@@ -1,7 +1,9 @@
 import dataclasses
+import time
 from typing import Union, Type, Any, List, Tuple, Callable, Dict, Optional
 
-from sqlalchemy import ForeignKey, Column, Sequence
+import sqlalchemy
+from sqlalchemy import ForeignKey, Column, Sequence, func
 from sqlalchemy.types import TypeEngine
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm.attributes import InstrumentedAttribute
@@ -56,6 +58,11 @@ def sql_field(type_: Union[Type[TypeEngine], TypeEngine], foreign_key: ForeignKe
     return dataclasses.field(**kwargs)
 
 
+def make_field__created_at():
+    return sql_field(sqlalchemy.Double, nullable=False, default=time.time,
+                     server_default=func.extract('epoch', func.now()))
+
+
 def get_columns(entity) -> List[InstrumentedAttribute]:
     columns = entity.__table__.c
     return list(columns)
